@@ -5,7 +5,7 @@ declare(strict_types=1);
 /*
  * eduVPN - End-user friendly VPN.
  *
- * Copyright: 2016-2022, The Commons Conservancy eduVPN Programme
+ * Copyright: 2016-2023, The Commons Conservancy eduVPN Programme
  * SPDX-License-Identifier: AGPL-3.0+
  */
 
@@ -47,6 +47,42 @@ class Config
         return $this->requireStringArray('profileIdList', []);
     }
 
+    /**
+     * User to use to run the OpenVPN server process.
+     */
+    public function vpnUser(): string
+    {
+        if (null !== $vpnUser = $this->optionalString('vpnUser')) {
+            return $vpnUser;
+        }
+
+        // rudimentary OS detection
+        if (FileIO::exists('/etc/debian_version')) {
+            // Debian & Ubuntu
+            return 'nobody';
+        }
+
+        return 'openvpn';
+    }
+
+    /**
+     * Group to use to run the OpenVPN server process.
+     */
+    public function vpnGroup(): string
+    {
+        if (null !== $vpnGroup = $this->optionalString('vpnGroup')) {
+            return $vpnGroup;
+        }
+
+        // rudimentary OS detection
+        if (FileIO::exists('/etc/debian_version')) {
+            // Debian & Ubuntu
+            return 'nogroup';
+        }
+
+        return 'openvpn';
+    }
+
     /**
      * @psalm-suppress UnresolvableInclude
      */
