@@ -5,7 +5,7 @@ declare(strict_types=1);
 /*
  * eduVPN - End-user friendly VPN.
  *
- * Copyright: 2016-2022, The Commons Conservancy eduVPN Programme
+ * Copyright: 2016-2023, The Commons Conservancy eduVPN Programme
  * SPDX-License-Identifier: AGPL-3.0+
  */
 
@@ -13,6 +13,4 @@ namespace Vpn\Node\Exception;
 
 use Exception;
 
-class ConnectionException extends Exception
-{
-}
+class ConnectionException extends Exception {}
