@@ -5,21 +5,17 @@ declare(strict_types=1);
 /*
  * eduVPN - End-user friendly VPN.
  *
- * Copyright: 2016-2022, The Commons Conservancy eduVPN Programme
+ * Copyright: 2016-2023, The Commons Conservancy eduVPN Programme
  * SPDX-License-Identifier: AGPL-3.0+
  */
 
 namespace Vpn\Node;
 
-use RuntimeException;
-
 class Syslog implements LogInterface
 {
     public function __construct(string $appName)
     {
-        if (false === openlog($appName, LOG_PERROR | LOG_ODELAY, LOG_USER)) {
-            throw new RuntimeException('unable to open syslog');
-        }
+        openlog($appName, LOG_PERROR | LOG_ODELAY, LOG_USER);
     }
 
     public function __destruct()
